.. _chaining:

Search Chaining
===============

**Search Chaining** break the modeling procedure down into a series of linked model-fits, providing
automated and efficient fits to the most complex lens models

Checkout
`Chapter 3 of the HowToGalaxy lectures <https://pyautogalaxy.readthedocs.io/en/latest/howtogalaxy/chapter_3_search_chaining.html>`_
for a complete description.